Index: /trunk/src/VBox/Frontends/VirtualBox/Makefile.kmk
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/Makefile.kmk	(revision 83655)
+++ /trunk/src/VBox/Frontends/VirtualBox/Makefile.kmk	(revision 83656)
@@ -621,5 +621,5 @@
 	src/manager/UIErrorPane.h \
 	src/manager/UITaskCloudAcquireInstances.h \
-	src/manager/UITaskCloudGetInstanceInfo.h \
+	src/manager/UITaskCloudRefreshMachineInfo.h \
 	src/manager/UIToolPaneGlobal.h \
 	src/manager/UIToolPaneMachine.h \
@@ -1072,5 +1072,5 @@
 	src/manager/UIErrorPane.cpp \
 	src/manager/UITaskCloudAcquireInstances.cpp \
-	src/manager/UITaskCloudGetInstanceInfo.cpp \
+	src/manager/UITaskCloudRefreshMachineInfo.cpp \
 	src/manager/UIToolPaneGlobal.cpp \
 	src/manager/UIToolPaneMachine.cpp \
Index: unk/src/VBox/Frontends/VirtualBox/src/manager/UITaskCloudGetInstanceInfo.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/UITaskCloudGetInstanceInfo.cpp	(revision 83655)
+++ 	(revision )
@@ -1,42 +1,0 @@
-/* $Id$ */
-/** @file
- * VBox Qt GUI - UITaskCloudGetInstanceInfo class implementation.
- */
-
-/*
- * Copyright (C) 2020 Oracle Corporation
- *
- * This file is part of VirtualBox Open Source Edition (OSE), as
- * available from http://www.virtualbox.org. This file is free software;
- * you can redistribute it and/or modify it under the terms of the GNU
- * General Public License (GPL) as published by the Free Software
- * Foundation, in version 2 as it comes in the "COPYING" file of the
- * VirtualBox OSE distribution. VirtualBox OSE is distributed in the
- * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
- */
-
-/* GUI includes: */
-#include "UICloudNetworkingStuff.h"
-#include "UITaskCloudGetInstanceInfo.h"
-
-
-UITaskCloudGetInstanceInfo::UITaskCloudGetInstanceInfo(const CCloudMachine &comCloudMachine)
-    : UITask(Type_CloudGetInstanceState)
-    , m_comCloudMachine(comCloudMachine)
-{
-}
-
-QString UITaskCloudGetInstanceInfo::errorInfo()
-{
-    m_mutex.lock();
-    const QString strErrorInfo = m_strErrorInfo;
-    m_mutex.unlock();
-    return strErrorInfo;
-}
-
-void UITaskCloudGetInstanceInfo::run()
-{
-    m_mutex.lock();
-    refreshCloudMachineInfo(m_comCloudMachine, m_strErrorInfo);
-    m_mutex.unlock();
-}
Index: unk/src/VBox/Frontends/VirtualBox/src/manager/UITaskCloudGetInstanceInfo.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/UITaskCloudGetInstanceInfo.h	(revision 83655)
+++ 	(revision )
@@ -1,67 +1,0 @@
-/* $Id$ */
-/** @file
- * VBox Qt GUI - UITaskCloudGetInstanceInfo class declaration.
- */
-
-/*
- * Copyright (C) 2020 Oracle Corporation
- *
- * This file is part of VirtualBox Open Source Edition (OSE), as
- * available from http://www.virtualbox.org. This file is free software;
- * you can redistribute it and/or modify it under the terms of the GNU
- * General Public License (GPL) as published by the Free Software
- * Foundation, in version 2 as it comes in the "COPYING" file of the
- * VirtualBox OSE distribution. VirtualBox OSE is distributed in the
- * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
- */
-
-#ifndef FEQT_INCLUDED_SRC_manager_UITaskCloudGetInstanceInfo_h
-#define FEQT_INCLUDED_SRC_manager_UITaskCloudGetInstanceInfo_h
-#ifndef RT_WITHOUT_PRAGMA_ONCE
-# pragma once
-#endif
-
-/* Qt includes: */
-#include <QMap>
-#include <QMutex>
-
-/* GUI includes: */
-#include "UITask.h"
-
-/* COM includes: */
-#include "COMEnums.h"
-#include "CCloudMachine.h"
-
-
-/** UITask extension used to get cloud instance state. */
-class UITaskCloudGetInstanceInfo : public UITask
-{
-    Q_OBJECT;
-
-public:
-
-    /** Constructs task taking @a comCloudMachine as data.
-      * @param  comCloudMachine  Brings the cloud VM wrapper. */
-    UITaskCloudGetInstanceInfo(const CCloudMachine &comCloudMachine);
-
-    /** Returns error info. */
-    QString errorInfo();
-
-protected:
-
-    /** Contains the task body. */
-    virtual void run() /* override */;
-
-private:
-
-    /** Holds the mutex to access m_comCloudMachine member. */
-    mutable QMutex  m_mutex;
-
-    /** Holds the cloud machine object. */
-    CCloudMachine  m_comCloudMachine;
-
-    /** Holds the error info. */
-    QString  m_strErrorInfo;
-};
-
-#endif /* !FEQT_INCLUDED_SRC_manager_UITaskCloudGetInstanceInfo_h */
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/UITaskCloudRefreshMachineInfo.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/UITaskCloudRefreshMachineInfo.cpp	(revision 83656)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/UITaskCloudRefreshMachineInfo.cpp	(revision 83656)
@@ -0,0 +1,42 @@
+/* $Id$ */
+/** @file
+ * VBox Qt GUI - UITaskCloudRefreshMachineInfo class implementation.
+ */
+
+/*
+ * Copyright (C) 2020 Oracle Corporation
+ *
+ * This file is part of VirtualBox Open Source Edition (OSE), as
+ * available from http://www.virtualbox.org. This file is free software;
+ * you can redistribute it and/or modify it under the terms of the GNU
+ * General Public License (GPL) as published by the Free Software
+ * Foundation, in version 2 as it comes in the "COPYING" file of the
+ * VirtualBox OSE distribution. VirtualBox OSE is distributed in the
+ * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
+ */
+
+/* GUI includes: */
+#include "UICloudNetworkingStuff.h"
+#include "UITaskCloudRefreshMachineInfo.h"
+
+
+UITaskCloudRefreshMachineInfo::UITaskCloudRefreshMachineInfo(const CCloudMachine &comCloudMachine)
+    : UITask(Type_CloudGetInstanceState)
+    , m_comCloudMachine(comCloudMachine)
+{
+}
+
+QString UITaskCloudRefreshMachineInfo::errorInfo()
+{
+    m_mutex.lock();
+    const QString strErrorInfo = m_strErrorInfo;
+    m_mutex.unlock();
+    return strErrorInfo;
+}
+
+void UITaskCloudRefreshMachineInfo::run()
+{
+    m_mutex.lock();
+    refreshCloudMachineInfo(m_comCloudMachine, m_strErrorInfo);
+    m_mutex.unlock();
+}
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/UITaskCloudRefreshMachineInfo.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/UITaskCloudRefreshMachineInfo.h	(revision 83656)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/UITaskCloudRefreshMachineInfo.h	(revision 83656)
@@ -0,0 +1,67 @@
+/* $Id$ */
+/** @file
+ * VBox Qt GUI - UITaskCloudRefreshMachineInfo class declaration.
+ */
+
+/*
+ * Copyright (C) 2020 Oracle Corporation
+ *
+ * This file is part of VirtualBox Open Source Edition (OSE), as
+ * available from http://www.virtualbox.org. This file is free software;
+ * you can redistribute it and/or modify it under the terms of the GNU
+ * General Public License (GPL) as published by the Free Software
+ * Foundation, in version 2 as it comes in the "COPYING" file of the
+ * VirtualBox OSE distribution. VirtualBox OSE is distributed in the
+ * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
+ */
+
+#ifndef FEQT_INCLUDED_SRC_manager_UITaskCloudRefreshMachineInfo_h
+#define FEQT_INCLUDED_SRC_manager_UITaskCloudRefreshMachineInfo_h
+#ifndef RT_WITHOUT_PRAGMA_ONCE
+# pragma once
+#endif
+
+/* Qt includes: */
+#include <QMap>
+#include <QMutex>
+
+/* GUI includes: */
+#include "UITask.h"
+
+/* COM includes: */
+#include "COMEnums.h"
+#include "CCloudMachine.h"
+
+
+/** UITask extension used to get cloud instance state. */
+class UITaskCloudRefreshMachineInfo : public UITask
+{
+    Q_OBJECT;
+
+public:
+
+    /** Constructs task taking @a comCloudMachine as data.
+      * @param  comCloudMachine  Brings the cloud VM wrapper. */
+    UITaskCloudRefreshMachineInfo(const CCloudMachine &comCloudMachine);
+
+    /** Returns error info. */
+    QString errorInfo();
+
+protected:
+
+    /** Contains the task body. */
+    virtual void run() /* override */;
+
+private:
+
+    /** Holds the mutex to access m_comCloudMachine member. */
+    mutable QMutex  m_mutex;
+
+    /** Holds the cloud machine object. */
+    CCloudMachine  m_comCloudMachine;
+
+    /** Holds the error info. */
+    QString  m_strErrorInfo;
+};
+
+#endif /* !FEQT_INCLUDED_SRC_manager_UITaskCloudRefreshMachineInfo_h */
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/UIVirtualMachineItemCloud.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/UIVirtualMachineItemCloud.cpp	(revision 83655)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/UIVirtualMachineItemCloud.cpp	(revision 83656)
@@ -25,5 +25,5 @@
 #include "UIIconPool.h"
 #include "UIMessageCenter.h"
-#include "UITaskCloudGetInstanceInfo.h"
+#include "UITaskCloudRefreshMachineInfo.h"
 #include "UIThreadPool.h"
 #include "UIVirtualMachineItemCloud.h"
@@ -279,5 +279,5 @@
     if (!m_pTask)
     {
-        m_pTask = new UITaskCloudGetInstanceInfo(m_comCloudMachine);
+        m_pTask = new UITaskCloudRefreshMachineInfo(m_comCloudMachine);
         connect(uiCommon().threadPoolCloud(), &UIThreadPool::sigTaskComplete,
                 this, &UIVirtualMachineItemCloud::sltHandleGetCloudInstanceInfoDone);

Index: /trunk/src/VBox/Frontends/VirtualBox/src/globals/UICloudNetworkingStuff.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/globals/UICloudNetworkingStuff.cpp	(revision 83655)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/globals/UICloudNetworkingStuff.cpp	(revision 83656)
@@ -231,8 +231,8 @@
     else
     {
         /* Show "Read cloud machine state" progress: */
         if (pParent)
             msgCenter().showModalProgressDialog(comProgress,
-                                                UICommon::tr("Read cloud machine state ..."),
+                                                UICommon::tr("Refresh cloud machine information ..."),
                                                 ":/progress_reading_appliance_90px.png", pParent, 0);
         else
@@ -231,8 +231,8 @@
     else
     {
-        /* Show "Read cloud machine state" progress: */
+        /* Show "Refresh cloud machine information" progress: */
         if (pParent)
             msgCenter().showModalProgressDialog(comProgress,